@@ -1,5 +1,5 @@
 /*
-  Copyright 2013-2015 Laurent Montel <montel@kde.org>
+  Copyright 2013-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ class KDEPIMAKONADI_EXPORT AddEmailDiplayJob : public KJob
 public:
     explicit AddEmailDiplayJob(const QString &email, QWidget *parentWidget, QObject *parent = nullptr);
 
-    ~AddEmailDiplayJob();
+    ~AddEmailDiplayJob() override;
     void setShowAsHTML(bool html);
     void setRemoteContent(bool b);
     void setContact(const Akonadi::Item &contact);
@@ -47,11 +47,6 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void slotSearchDone(KJob *))
-    Q_PRIVATE_SLOT(d, void slotAddModifyContactDone(KJob *))
-    Q_PRIVATE_SLOT(d, void slotCollectionsFetched(KJob *))
-    Q_PRIVATE_SLOT(d, void slotResourceCreationDone(KJob *))
     //@endcond
 };
 }
